#ifndef __BUNDLE_CREATOR_H
#define __BUNDLE_CREATOR_H

#include <QtCore>

class BundleCreator : public QObject
{
    Q_OBJECT
public:
    BundleCreator(void);
    ~BundleCreator(void) override;
};

#endif